==> gnumeric-1.1.2.tar.gz: gnumeric-1.1.2/src/gnm-marshalers.h <==

#ifndef __gnm__MARSHAL_H__
#define __gnm__MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:POINTER (gnm-marshalers.list:23) */
extern void gnm__BOOLEAN__POINTER (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* INT:INT (gnm-marshalers.list:24) */
extern void gnm__INT__INT (GClosure     *closure,
                           GValue       *return_value,
                           guint         n_param_values,
                           const GValue *param_values,
                           gpointer      invocation_hint,
                           gpointer      marshal_data);

/* NONE:INT,INT (gnm-marshalers.list:25) */
extern void gnm__VOID__INT_INT (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);
#define gnm__NONE__INT_INT	gnm__VOID__INT_INT

/* NONE:NONE (gnm-marshalers.list:26) */
#define gnm__VOID__VOID	g_cclosure_marshal_VOID__VOID
#define gnm__NONE__NONE	gnm__VOID__VOID

/* NONE:POINTER (gnm-marshalers.list:27) */
#define gnm__VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define gnm__NONE__POINTER	gnm__VOID__POINTER

/* POINTER:INT,INT (gnm-marshalers.list:28) */
extern void gnm__POINTER__INT_INT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* NONE:STRING (gnm-marshalers.list:29) */
#define gnm__VOID__STRING	g_cclosure_marshal_VOID__STRING
#define gnm__NONE__STRING	gnm__VOID__STRING

G_END_DECLS

#endif /* __gnm__MARSHAL_H__ */

==> gnumeric_1.4.3.orig.tar.gz: gnumeric-1.4.3/src/gnm-marshalers.h <==

#ifndef __gnm__MARSHAL_H__
#define __gnm__MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:OBJECT (gnm-marshalers.list:23) */
extern void gnm__BOOLEAN__OBJECT (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);

/* BOOLEAN:POINTER (gnm-marshalers.list:24) */
extern void gnm__BOOLEAN__POINTER (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* INT:INT (gnm-marshalers.list:25) */
extern void gnm__INT__INT (GClosure     *closure,
                           GValue       *return_value,
                           guint         n_param_values,
                           const GValue *param_values,
                           gpointer      invocation_hint,
                           gpointer      marshal_data);

/* POINTER:INT,INT (gnm-marshalers.list:26) */
extern void gnm__POINTER__INT_INT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* POINTER:VOID (gnm-marshalers.list:27) */
extern void gnm__POINTER__VOID (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);

/* VOID:INT,INT (gnm-marshalers.list:28) */
extern void gnm__VOID__INT_INT (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);

G_END_DECLS

#endif /* __gnm__MARSHAL_H__ */
